search — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

# search

class `camelot.view.controls.search.` `SimpleSearchControl`(parent)

  A control that displays a single text field in which search keywords can be typed

  emits a search and a cancel signal if the user starts or cancels the search

  `search`(search_text)

    Start searching for search_text

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

Comments
blog comments powered by Disqus